/*
 * RTEMS Project (http://www.rtems.org/)
 *
 * Copyright 2013 Chris Johns (chrisj@rtems.org)
 */

/**
 * A hello world with a shell.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <termios.h>

#include <rtems.h>
#include <rtems/error.h>
#include <rtems/shell.h>

#if pc586
#include "pc386-gdb.h"
int remote_debug;
#endif

/**
 * Start the RTEMS Shell.
 */
static void
shell_start (void)
{
  rtems_status_code sc;
  printf ("Starting shell....\n\n");
  sc = rtems_shell_init ("fstst", 60 * 1024, 150, "/dev/console", 0, 1, NULL);
  if (sc != RTEMS_SUCCESSFUL)
    printf ("error: starting shell: %s (%d)\n", rtems_status_text (sc), sc);
}

int
main (int argc, char* argv[])
{
  struct termios term;

#if pc586
  int arg;
  for (arg = 1; arg < argc; arg++)
    if (strcmp (argv[arg], "--gdb") == 0)
      pc386_gdb_init ();
#endif

  if (tcgetattr(fileno(stdout), &term) < 0)
    printf ("error: cannot get terminal attributes: %s\n", strerror (errno));
  cfsetispeed (&term, B115200);
  cfsetospeed (&term, B115200);
  if (tcsetattr (fileno(stdout), TCSADRAIN, &term) < 0)
    printf ("error: cannot set terminal attributes: %s\n", strerror (errno));

  if (tcgetattr(fileno(stdin), &term) < 0)
    printf ("error: cannot get terminal attributes: %s\n", strerror (errno));
  cfsetispeed (&term, B115200);
  cfsetospeed (&term, B115200);
  if (tcsetattr (fileno(stdin), TCSADRAIN, &term) < 0)
    printf ("error: cannot set terminal attributes: %s\n", strerror (errno));

  printf ("\nRTEMS says hello\n\n");

  while (true)
    shell_start ();

  rtems_task_delete (RTEMS_SELF);

  return 0;
}

#if pc586
void
rtems_fatal_error_occurred (uint32_t code)
{
  printf ("fatal error: %08lx\n", code);
  for (;;);
}
#endif
